API
===


.. toctree::
   :maxdepth: 4



.. autosummary::
   :toctree: _autosummary

   typez
   metadsl
   metadsl.matching
   metadsl.rules
   metadsl.normalized
   metadsl.typing_tools
   metadsl.dict_tools
   metadsl_core
   metadsl_core.abstraction
   metadsl_core.boolean
   metadsl_core.conversion
   metadsl_core.either
   metadsl_core.function
   metadsl_core.integer
   metadsl_core.maybe
   metadsl_core.numpy_engine
   metadsl_core.numpy
   metadsl_core.pair
   metadsl_core.rules
   metadsl_core.vec
   metadsl_llvm
   metadsl_llvm.ctypes
   metadsl_llvm.llvmlite_binding
   metadsl_llvm.llmvlite_ir
   metadsl_llvm.pure
   metadsl_visualize
   metadsl_visualize.typez
   metadsl_visualize.visualize
